@@ -1,7 +1,7 @@
 
 fn main() {
     // Skip linking on docs.rs: https://docs.rs/about/builds#detecting-docsrs
-    let building_docs = std::env::var("DOC_RS").is_ok();
+    let building_docs = std::env::var("DOCS_RS").is_ok();
     if building_docs {
         return;
     }
@@ -35,4 +35,4 @@ fn main() {
     #[cfg(target_os = "macos")]
     println!("cargo:rustc-link-lib=dylib=c++");
 }
-    
\ No newline at end of file
+    
